notifySoft method

  1. @override
void notifySoft()
override

Recomputes this value and only notifies subscribers when the result changed.

Use this to refresh a computed value whose dependencies are not tracked automatically but whose derived output may have changed.

Implementation

@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
@override
void notifySoft() => raw.notifySoft();