equals property
Optional equality function used to suppress propagation.
Return true when the newly computed value should be treated as equal to
the previous one.
Implementation
final bool Function(T current, T? previous)? equals;
Optional equality function used to suppress propagation.
Return true when the newly computed value should be treated as equal to
the previous one.
final bool Function(T current, T? previous)? equals;