getter property
T Function()
getter
final
Function that computes the value while this node is the active subscriber.
Implementation
final T Function() getter;
Function that computes the value while this node is the active subscriber.
final T Function() getter;