ConstantImpl<T> class
- Implemented types
-
- ReadonlyImpl<
T>
- ReadonlyImpl<
- Available extensions
Constructors
- ConstantImpl(T value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- peek → T
-
The current value without establishing a reactive dependency.
no setteroverride
-
raw
→ Readable<
T> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
T> -
Available on Readable<
A broadcast stream of later visible changes to this readable.T> , provided by the JoltUtilsStreamExtension extensionno setter - value → T
-
The current value using this view's normal read semantics.
no setteroverride
Methods
-
call(
) → T -
Available on Readable<
The current value using callable syntax.T> , provided by the JoltUtilsReadableExtension extension -
derived<
U> (U computed(T value)) → Computed< U> -
Available on Readable<
A computed value derived from this readable.T> , provided by the JoltUtilsReadableExtension extension -
get(
) → T -
Available on Readable<
The current value using method syntax.T> , provided by the JoltUtilsReadableExtension extension -
listen(
void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError, bool immediately = false}) → StreamSubscription< T> -
Available on Readable<
Subscribes to later visible changes to this readable.T> , provided by the JoltUtilsStreamExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
until(
bool predicate(T value), {bool? detach}) → Until< T> -
Available on Readable<
Waits until the value satisfies a condition.T> , provided by the JoltUtilsUntilExtension extension -
untilChanged(
{bool? detach}) → Until< T> -
Available on Readable<
Waits until the value changes from its current value.T> , provided by the JoltUtilsUntilExtension extension -
untilWhen<
U> (U value, {bool? detach}) → Until< T> -
Available on Readable<
Waits until the reactive value equalsT> , provided by the JoltUtilsUntilExtension extensionvalue.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited