DisposableNodeMixin mixin

Mixin providing base disposal functionality for reactive nodes.

Sets ReactiveFlags.disposed so the node is no longer reactive. Implements common disposal logic and calls onDispose for custom cleanup.

Example:

class MyNode<T> with DisposableNodeMixin implements DisposableNode {
  @override
  void onDispose() {
    // Custom cleanup logic
  }
}
Implemented types
Mixin applications

Properties

deps Link?
First dependency link in the chain.
getter/setter pairinherited
depsTail Link?
Last dependency link in the chain.
getter/setter pairinherited
flags int
Reactive flags for this node.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether this node has been disposed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subs Link?
First subscriber link in the chain.
getter/setter pairinherited
subsTail Link?
Last subscriber link in the chain.
getter/setter pairinherited

Methods

dispose() → void
Disposes this node and cleans up resources.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → void
Called when the node is being disposed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited