EffectImpl class

Implemented types

Constructors

EffectImpl(void fn(), {bool lazy = false, bool detach = false, JoltDebugOption? debug})
EffectImpl.custom(void fn(), {required EffectNode node})
EffectImpl.lazy(void fn(), {bool detach = false, JoltDebugOption? debug})
factory

Properties

fn → void Function()
The function that defines the effect's behavior.
final
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether this node has been disposed.
no setteroverride
raw EffectNode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes this node and cleans up resources.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCleanup(Disposer fn) → void
Registers a cleanup callback for this effect.
override
run() → void
Manually runs the effect function.
override
toString() String
A string representation of this object.
inherited
track<T>(T fn(), [bool purge = true]) → T

Operators

operator ==(Object other) bool
The equality operator.
inherited