fn property
void Function()
fn
final
Side-effect body executed on the initial run and scheduled reruns.
Implementation
final void Function() fn;
Side-effect body executed on the initial run and scheduled reruns.
final void Function() fn;