onCleanup method
Registers a cleanup function to run when this scope disposes.
The fn callback should release resources owned by this scope.
Example:
scope.onCleanup(() => subscription.cancel());
Implementation
@override
void onCleanup(Disposer fn) => raw.onCleanup(fn);