run<T> method

  1. @override
T run<T>(
  1. T fn()
)
override

Runs fn with this scope set as the active scope.

The fn callback can create effects, signals, and cleanups that should belong to this scope.

Example:

final result = scope.run(() => 42);

Implementation

@override
T run<T>(T Function() fn) => raw.run(fn);