update method

  1. @override
bool update()
override

Resets transient scheduling flags on this scope.

Effect scopes do not compute values, so this keeps the scope active in the graph and always reports success.

Implementation

@override
bool update() {
  flags = ReactiveFlags.mutable;
  return true;
}