unlinked static method

void unlinked(
  1. ReactiveNode target,
  2. Link link
)

Notifies the debug system that a reactive node was unlinked from a dependency.

This method should be called when a dependency relationship is removed between target and another node via link.

Implementation

@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
static void unlinked(ReactiveNode target, Link link) {
  getDebug(target)?.call(DebugNodeOperationType.unlinked, target, link);
  JoltDevTools.handleNodeLifecycle(DebugNodeOperationType.unlinked, target,
      link: link);
}