JoltDevTools class abstract final

VM service extension hooks used by Jolt DevTools.

Most members on this type are internal. The public class exists so core debugging support can expose a stable type from package:jolt/core.dart.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(ReactiveNode target, JoltDebugOption? option) → void
Notifies the debug system that a reactive node was created.
dispose(ReactiveNode target) → void
Notifies the debug system that a reactive node was disposed.
effect(ReactiveNode target) → void
Notifies the debug system that an effect was executed.
get(ReactiveNode target) → void
Notifies the debug system that a reactive node's value was accessed (get operation).
notify(ReactiveNode target) → void
Notifies the debug system that a reactive node notified its subscribers.
set(ReactiveNode target) → void
Notifies the debug system that a reactive node's value was set (set operation).
setDebug(Object target, JoltDebugFn? fn) → void
Sets a custom debug function for a specific target object.