JoltStreamHelper class abstract final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createWatchedStreamController<T>(Readable<T> readable, {bool sync = false}) → StreamController<T>
getOrCreateStreamController<T>(Readable<T> readable) → StreamController<T>
getStream<T>(Readable<T> readable) → Stream<T>
getStreamController<T>(Readable<T> obj) → StreamController<T>?