ReactiveFlags class abstract final

Bit flags that describe a ReactiveNode's reactive state.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dirty → const int
Node needs to be updated.
hasChildEffect → const int
Node owns at least one child effect or effect scope.
mutable → const int
Node can have dependencies and be updated.
none → const int
No flags set - node is inactive.
pending → const int
Node is pending update.
recursed → const int
Node is in recursive update.
recursedCheck → const int
Node is being checked for recursion.
watching → const int
Node is being watched by effects.