update abstract method

bool update()

Recomputes or refreshes this node when it is dirty.

Returns true when the observable value changed and shallow propagation to subscribers may be required.

Implementation

bool update();