ReadonlyImpl<T> class

Implemented types
Implementers
Available extensions

Constructors

ReadonlyImpl(Readable<T> raw)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
peek → T
The current value without establishing a reactive dependency.
no setteroverride
raw Readable<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>

Available on Readable<T>, provided by the JoltUtilsStreamExtension extension

A broadcast stream of later visible changes to this readable.
no setter
value → T
The current value using this view's normal read semantics.
no setteroverride

Methods

call() → T

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

The current value using callable syntax.
derived<U>(U computed(T value)) Computed<U>

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

A computed value derived from this readable.
get() → T

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

The current value using method syntax.
listen(void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError, bool immediately = false}) StreamSubscription<T>

Available on Readable<T>, provided by the JoltUtilsStreamExtension extension

Subscribes to later visible changes to this readable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
until(bool predicate(T value), {bool? detach}) Until<T>

Available on Readable<T>, provided by the JoltUtilsUntilExtension extension

Waits until the value satisfies a condition.
untilChanged({bool? detach}) Until<T>

Available on Readable<T>, provided by the JoltUtilsUntilExtension extension

Waits until the value changes from its current value.
untilWhen<U>(U value, {bool? detach}) Until<T>

Available on Readable<T>, provided by the JoltUtilsUntilExtension extension

Waits until the reactive value equals value.

Operators

operator ==(Object other) bool
The equality operator.
inherited