SignalImpl<T> class

Implemented types
Implementers
Available extensions

Constructors

SignalImpl(T? value, {JoltDebugOption? debug})

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether this node has been disposed.
no setteroverride
peek → T
The current value without establishing a reactive dependency.
no setteroverride
raw SignalNode<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>

Available on Readable<T>, provided by the JoltUtilsStreamExtension extension

A broadcast stream of later visible changes to this readable.
no setter
value ↔ T
The current value using this signal's tracked read semantics.
getter/setter pairoverride

Methods

call() → T

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

The current value using callable syntax.
derived<U>(U computed(T value)) Computed<U>

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

A computed value derived from this readable.
dispose() → void
Disposes this signal and removes it from future propagation.
override
get() → T

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

The current value using method syntax.
listen(void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError, bool immediately = false}) StreamSubscription<T>

Available on Readable<T>, provided by the JoltUtilsStreamExtension extension

Subscribes to later visible changes to this readable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify() → void
Notifies dependents without writing a new value.
override
readonly() Readonly<T>

Available on Signal<T>, provided by the JoltSignalReadonlyExtension extension

Returns a cached read-only view of this signal.
set(T value) → T

Available on Writable<T>, provided by the JoltUtilsWritableExtension extension

Sets value and returns it.
toString() String
A string representation of this object.
override
until(bool predicate(T value), {bool? detach}) Until<T>

Available on Readable<T>, provided by the JoltUtilsUntilExtension extension

Waits until the value satisfies a condition.
untilChanged({bool? detach}) Until<T>

Available on Readable<T>, provided by the JoltUtilsUntilExtension extension

Waits until the value changes from its current value.
untilWhen<U>(U value, {bool? detach}) Until<T>

Available on Readable<T>, provided by the JoltUtilsUntilExtension extension

Waits until the reactive value equals value.
update(T updater(T value)) → T

Available on Writable<T>, provided by the JoltUtilsWritableExtension extension

Sets a new value derived from the current value.

Operators

operator ==(Object other) bool
The equality operator.
inherited