notify method
Notifies dependents without writing a new value.
Use notify after mutating data in place or when this signal should flush subscribers even though the stored reference stays the same.
Implementation
@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
@override
void notify() => raw.notify();