getActiveScope function
The effect scope that currently owns newly created effects.
Implementation
@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
EffectScopeNode? getActiveScope() => activeScope;
The effect scope that currently owns newly created effects.
@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
EffectScopeNode? getActiveScope() => activeScope;