reduce method
Reduces the set to a single value using the given combine function.
This is a non-mutating operation.
Implementation
@override
E reduce(E Function(E value, E element) combine) => value.reduce(combine);
Reduces the set to a single value using the given combine function.
This is a non-mutating operation.
@override
E reduce(E Function(E value, E element) combine) => value.reduce(combine);