AsyncSignalImpl<T> class
- Inheritance
-
- Object
- SignalImpl<
AsyncState< T> > - AsyncSignalImpl
- Implemented types
-
- AsyncSignal<
T>
- AsyncSignal<
Constructors
-
AsyncSignalImpl({AsyncSource<
T> ? source, AsyncState<T> ? initialValue, JoltDebugOption? debug})
Properties
- data → T?
-
Gets the data from the current async state.
no setteroverride
- error → Object?
-
The error from the current async state, if any.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether this node has been disposed.
no setterinherited
- isError → bool
-
Whether the current state represents an error.
no setteroverride
- isLoading → bool
-
Whether the current state represents a loading operation.
no setteroverride
- isSuccess → bool
-
Whether the current state represents a successful operation with data.
no setteroverride
-
peek
→ AsyncState<
T> -
The current value without establishing a reactive dependency.
no setterinherited
-
raw
→ SignalNode<
AsyncState< T> > -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace from the current async error state, if any.
no setteroverride
-
value
↔ AsyncState<
T> -
The current value using this signal's tracked read semantics.
getter/setter pairinherited
Methods
-
dispose(
) → void -
Disposes this signal and removes it from future propagation.
override
-
fetch(
AsyncSource< T> source) → Future<void> -
Replaces the current source and subscribes to
source.override -
map<
R> ({R loading()?, R success(T)?, R error(Object?, StackTrace?)?}) → R? -
Maps the current async state to a value with optional handlers.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
) → void -
Notifies dependents without writing a new value.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited