notify method
Notifies dependents that this computed value should be treated as changed.
Use notify when external state affected by getter changed without
flowing through tracked dependencies.
Implementation
@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
@override
void notify() => raw.notify();