EffectScopeImpl class
- Implemented types
Constructors
- EffectScopeImpl({bool detach = false, JoltDebugOption? debug})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether this node has been disposed.
no setteroverride
- raw → EffectScopeNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Disposes this node and cleans up resources.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCleanup(
Disposer fn) → void -
Registers a cleanup function to run when this scope disposes.
override
-
run<
T> (T fn()) → T -
Runs
fnwith this scope set as the active scope.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited