run<T> method
Runs fn with this scope set as the active scope.
The fn callback can create effects, signals, and cleanups that should
belong to this scope.
Example:
final result = scope.run(() => 42);
Implementation
@override
T run<T>(T Function() fn) => raw.run(fn);