notify static method
Notifies the debug system that a reactive node notified its subscribers.
This method should be called when target notifies its subscribers
about a value change.
Implementation
@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
static void notify(ReactiveNode target) {
getDebug(target)?.call(DebugNodeOperationType.notify, target, null);
JoltDevTools.handleNodeLifecycle(DebugNodeOperationType.notify, target);
}