ReactiveNode class abstract
Base node in the reactive dependency graph.
A reactive node can depend on other nodes through deps and can be observed by other nodes through subs. Subclasses define how values are updated, cached, or disposed.
- Implementers
Constructors
- ReactiveNode({required int flags, Link? deps, Link? depsTail, Link? subs, Link? subsTail})
-
Creates a node with the supplied link state and
flags.
Properties
- deps ↔ Link?
-
First dependency link in the chain.
getter/setter pair
- depsTail ↔ Link?
-
Last dependency link in the chain.
getter/setter pair
- flags ↔ int
-
Reactive flags for this node.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subs ↔ Link?
-
First subscriber link in the chain.
getter/setter pair
- subsTail ↔ Link?
-
Last subscriber link in the chain.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unwatched(
) → void - Called when this node no longer has subscribers.
-
update(
) → bool - Recomputes or refreshes this node when it is dirty.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited