SignalImpl<T> class
- Implemented types
-
- Signal<
T>
- Signal<
- Implementers
- Available extensions
Constructors
- SignalImpl(T? value, {JoltDebugOption? debug})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether this node has been disposed.
no setteroverride
- peek → T
-
The current value without establishing a reactive dependency.
no setteroverride
-
raw
→ SignalNode<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
T> -
Available on Readable<
A broadcast stream of later visible changes to this readable.T> , provided by the JoltUtilsStreamExtension extensionno setter - value ↔ T
-
The current value using this signal's tracked read semantics.
getter/setter pairoverride
Methods
-
call(
) → T -
Available on Readable<
The current value using callable syntax.T> , provided by the JoltUtilsReadableExtension extension -
derived<
U> (U computed(T value)) → Computed< U> -
Available on Readable<
A computed value derived from this readable.T> , provided by the JoltUtilsReadableExtension extension -
dispose(
) → void -
Disposes this signal and removes it from future propagation.
override
-
get(
) → T -
Available on Readable<
The current value using method syntax.T> , provided by the JoltUtilsReadableExtension extension -
listen(
void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError, bool immediately = false}) → StreamSubscription< T> -
Available on Readable<
Subscribes to later visible changes to this readable.T> , provided by the JoltUtilsStreamExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
) → void -
Notifies dependents without writing a new value.
override
-
readonly(
) → Readonly< T> -
Available on Signal<
Returns a cached read-only view of this signal.T> , provided by the JoltSignalReadonlyExtension extension -
set(
T value) → T -
Available on Writable<
SetsT> , provided by the JoltUtilsWritableExtension extensionvalueand returns it. -
toString(
) → String -
A string representation of this object.
override
-
until(
bool predicate(T value), {bool? detach}) → Until< T> -
Available on Readable<
Waits until the value satisfies a condition.T> , provided by the JoltUtilsUntilExtension extension -
untilChanged(
{bool? detach}) → Until< T> -
Available on Readable<
Waits until the value changes from its current value.T> , provided by the JoltUtilsUntilExtension extension -
untilWhen<
U> (U value, {bool? detach}) → Until< T> -
Available on Readable<
Waits until the reactive value equalsT> , provided by the JoltUtilsUntilExtension extensionvalue. -
update(
T updater(T value)) → T -
Available on Writable<
Sets a new value derived from the current value.T> , provided by the JoltUtilsWritableExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited