SignalNode<T> constructor
SignalNode<T> (
- T? value, {
- JoltDebugOption? debug,
Creates a signal node initialized to value.
The same value is used for both the committed value and the pending value until the node is updated or notified.
Implementation
SignalNode(this.value, {JoltDebugOption? debug})
: pendingValue = value,
super(flags: ReactiveFlags.mutable) {
assert(() {
JoltDevTools.create(this, debug);
return true;
}());
}