WritableComputedImpl<T> class
- Inheritance
-
- Object
- ComputedImpl<
T> - WritableComputedImpl
- Implemented types
- Available extensions
Constructors
- WritableComputedImpl(T getter(), void setter(T), {bool equals(T current, T? previous)?, JoltDebugOption? debug})
- WritableComputedImpl.withPrevious(T getter(T?), void setter(T), {ComputedEqualsFn? equals, JoltDebugOption? debug})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether this node has been disposed.
no setterinherited
- peek → T
-
The current derived value without establishing a reactive dependency.
no setterinherited
-
raw
↔ ComputedNode<
T> -
latefinalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setter → void Function(T)
-
The function called when this computed value is set.
final
-
stream
→ Stream<
T> -
Available on Readable<
A broadcast stream of later visible changes to this readable.T> , provided by the JoltUtilsStreamExtension extensionno setter - value ↔ T
-
The current derived value using this computed value's tracked read semantics.
getter/setter pairinherited-getteroverride-setter
Methods
-
call(
) → T -
Available on Readable<
The current value using callable syntax.T> , provided by the JoltUtilsReadableExtension extension -
derived<
U> (U computed(T value)) → Computed< U> -
Available on Readable<
A computed value derived from this readable.T> , provided by the JoltUtilsReadableExtension extension -
dispose(
) → void -
Disposes this computed value and removes it from future propagation.
inherited
-
get(
) → T -
Available on Readable<
The current value using method syntax.T> , provided by the JoltUtilsReadableExtension extension -
listen(
void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError, bool immediately = false}) → StreamSubscription< T> -
Available on Readable<
Subscribes to later visible changes to this readable.T> , provided by the JoltUtilsStreamExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
) → void -
Notifies dependents that this computed value should be treated as changed.
inherited
-
notifySoft(
) → void -
Recomputes this value and only notifies subscribers when the result changed.
inherited
-
readonly(
) → Readonly< T> -
Available on Computed<
Returns a cached read-only view of this computed value.T> , provided by the JoltComputedReadonlyExtension extension -
readonly(
) → Readonly< T> -
Available on WritableComputed<
Returns a cached read-only view of this writable computed value.T> , provided by the JoltWritableComputedReadonlyExtension extension -
set(
T value) → T -
Available on Writable<
SetsT> , provided by the JoltUtilsWritableExtension extensionvalueand returns it. -
toString(
) → String -
A string representation of this object.
inherited
-
until(
bool predicate(T value), {bool? detach}) → Until< T> -
Available on Readable<
Waits until the value satisfies a condition.T> , provided by the JoltUtilsUntilExtension extension -
untilChanged(
{bool? detach}) → Until< T> -
Available on Readable<
Waits until the value changes from its current value.T> , provided by the JoltUtilsUntilExtension extension -
untilWhen<
U> (U value, {bool? detach}) → Until< T> -
Available on Readable<
Waits until the reactive value equalsT> , provided by the JoltUtilsUntilExtension extensionvalue. -
update(
T updater(T value)) → T -
Available on Writable<
Sets a new value derived from the current value.T> , provided by the JoltUtilsWritableExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited